# Drupal Resque Module

This module makes use of an existing php resque implementation:
https://github.com/resque/php-resque

This module extends DrupalQueue to be able to use Drupal\resque\Resque instead,
also being able to use Drupal\resque\ResqueUnique so that jobs with the same
payload key are not queued at any point in time.

This README is for interested developers.

## Requirements

  * Redis installed locally or use a remote server.
  * This module installed on the project via composer.

## How To Use

  * TBD
  * Worker instance initialization example - Redis installed locally:
    ```shell script
    REDIS_BACKEND=localhost:6379 QUEUE='*' COUNT=2 RESQUE_DRUPAL_ROOT=$(pwd) APP_INCLUDE=$RESQUE_DRUPAL_ROOT/modules/custom/resque/resque.app.php ../vendor/bin/resque
    ```
  * Worker instance initialization example - Docker4Drupal:
    ```yaml
    service:
      # ...
      resque-worker-1:
        image: wodby/drupal-php:$PHP_TAG
        container_name: "${PROJECT_NAME}_resque_worker_1"
        environment:
          PHP_SENDMAIL_PATH: /usr/sbin/sendmail -t -i -S mailhog:1025
          PROJECT_BASE_URL: $PROJECT_BASE_URL
          DB_HOST: $DB_HOST
          DB_USER: $DB_USER
          DB_PASSWORD: $DB_PASSWORD
          DB_NAME: $DB_NAME
          DB_DRIVER: $DB_DRIVER
          DB_PORT: $DB_PORT
          REDIS_BACKEND: redis:6379
          QUEUE: "*"
          COUNT: 2
          DRUPAL_ROOT: /var/www/html/web
          APP_INCLUDE: /var/www/html/web/modules/custom/resque/resque.app.php
        command: vendor/bin/resque
        volumes:
          - ./:/var/www/html:cached
    ```
    or manual separate process initialization for local development:
    ```shell script
    docker-compose exec php bash -c 'REDIS_BACKEND=localhost:6379 QUEUE="*" COUNT=2 RESQUE_DRUPAL_ROOT=$(pwd) APP_INCLUDE=$RESQUE_DRUPAL_ROOT/modules/custom/resque/resque.app.php ../vendor/bin/resque'
    ```
```
REDIS_BACKEND=redis:6379 QUEUE='*' COUNT=2 RESQUE_DRUPAL_ROOT=$(pwd) APP_INCLUDE=$RESQUE_DRUPAL_ROOT/modules/custom/resque/resque.app.inc ../vendor/bin/drush php:script ../vendor/bin/resque
```
```
dco exec php bash -c 'cd web/ && LOGGING=1 VVERBOSE=1 VERBOSE=1 REDIS_BACKEND=redis:6379 QUEUE='*' COUNT=2 DRUPAL_ROOT=$(pwd) APP_INCLUDE=$DRUPAL_ROOT/modules/custom/resque/resque.app.php ../vendor/bin/resque'
```

