<?php

/**
 * @file
 * The default app include file for the resque worker instance.
 */

use Drupal\Core\DrupalKernel;
use Symfony\Cmf\Component\Routing\RouteObjectInterface;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Routing\Route;

$kernel = NULL;
Resque_Event::listen('beforeFirstFork', function ($worker) {
  $default_site_id = 'default';
  $site_id = getenv('DRUPAL_SITE_ID') ?? $default_site_id;
  $drupal_root = getenv('DRUPAL_ROOT');
  $host = NULL;
  $sites_file = $drupal_root . '/sites/sites.php';

  // Handle multisite configuration.
  if (file_exists($sites_file)) {
    // ToDo: handle only the queues related to the specific sub site.
    if (($site_id !== $default_site_id)) {
      $sites = [];
      include_once $sites_file;
      /*
       * ToDo: Support definition of host value through env var with
       *  appropriate validation of the site id.
       */
      $host = array_search($site_id, $sites, TRUE);
      $_SERVER['HTTP_HOST'] = $host;
    }
  }
  // Resolve host url.
  $_SERVER['HTTPS'] = 'on';
  $_SERVER['HTTP_USER_AGENT'] = NULL;
  $_SERVER['REMOTE_ADDR'] = '127.0.0.1';
  $_SERVER['SERVER_PORT'] = NULL;
  $_SERVER['REQUEST_METHOD'] = 'GET';
  $_SERVER['REQUEST_URI'] = '/';
  $_SERVER['SERVER_SOFTWARE'] = NULL;
  $_SERVER['PHP_SELF'] = $_SERVER['REQUEST_URI'] . 'index.php';
  $_SERVER['SCRIPT_NAME'] = $_SERVER['PHP_SELF'];

  chdir(realpath($drupal_root));

  /* @var \Composer\Autoload\ClassLoader $class_loader */
  $class_loader = require_once $drupal_root . '/autoload.php';

  $files = glob($drupal_root . '*/modules/*/Resque/Job/*.php');
  foreach ($files as $file) {
    [$filename, $job, $resq, $src, $module_name] = array_reverse(explode('/', $file));
    if ($job !== 'Job' || $resq !== 'Resque' || $src !== 'src') {
      continue;
    }
    $dir = str_replace(implode('/', [$resq, $job, $filename]), '', $file);
    $class_loader->addPsr4('Drupal\\' . $module_name . '\\', $dir);
  }

  /*
   * @ToDo: Find a way how populate kernel into child processes without
   *   breaking. Or move kernel boot on the beforeProcess event.
   */
  $request = Request::createFromGlobals();
  $kernel = DrupalKernel::createFromRequest($request, $class_loader, 'prod');
  $kernel->boot();
  $kernel->preHandle($request);
  // Setup services which are normally initialized from within stack
  // middleware or during the request kernel event.
  if (PHP_SAPI !== 'cli') {
    $request->setSession($this->container->get('session'));
  }
  $request->attributes->set(RouteObjectInterface::ROUTE_OBJECT, new Route('<none>'));
  $request->attributes->set(RouteObjectInterface::ROUTE_NAME, '<none>');
  $kernel->getContainer()->get('request_stack')->push($request);
  $kernel->getContainer()->get('router.request_context')->fromRequest($request);
  $event_dispatcher = $kernel->getContainer()->get('event_dispatcher');
  if ($event_dispatcher instanceof EventDispatcherInterface) {
    $event_dispatcher->dispatch('resque.before_first_fork');
  }
});
